'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var styled = _interopDefault(require('styled-components'));

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _taggedTemplateLiteralLoose(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }

  strings.raw = raw;
  return strings;
}

function isValidParam(param) {
  var value = param[1];
  return typeof value === 'string' && value.length > 0;
}
/*
  Do not use URLSearchParams.

  URLSearchParams turns spaces into '+':
      https://developer.mozilla.org/en-US/docs/Web/API/URLSearchParams#examples

  Some email clients on mobile apps will render the '+' and not properly replace it with spaces.

  For the 'mailto' protocol, spaces should be percent encoded according to the spec:
      https://datatracker.ietf.org/doc/html/rfc6068#ref-STD66
*/


function percentEncodeParams(params) {
  return Object.entries(params).filter(isValidParam).map(function (_ref) {
    var key = _ref[0],
        value = _ref[1];
    return key + "=" + encodeURIComponent(value);
  }).join('&');
}

var _excluded = ["body", "subject", "children", "className", "email"];

var _templateObject;
var Obfuscated = /*#__PURE__*/styled.span(_templateObject || (_templateObject = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  &::after {\n    content: '@';\n  }\n"])));

function obfuscateEmail(email) {
  var _email$split = email.split('@'),
      username = _email$split[0],
      domain = _email$split[1];

  return React__default.createElement(React__default.Fragment, null, username, React__default.createElement(Obfuscated, null), domain);
}

function Email(_ref) {
  var _ref$body = _ref.body,
      body = _ref$body === void 0 ? '' : _ref$body,
      _ref$subject = _ref.subject,
      subject = _ref$subject === void 0 ? '' : _ref$subject,
      children = _ref.children,
      className = _ref.className,
      email = _ref.email,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  var _useState = React.useState(false),
      hovered = _useState[0],
      setHovered = _useState[1];

  var emailUrl = new URL("mailto:" + email); // https://github.com/whatwg/url/issues/18#issuecomment-369865339

  emailUrl.search = percentEncodeParams({
    body: body,
    subject: subject
  });

  function handleHover() {
    setHovered(true);
  }

  var displayText = children || email;
  var obfuscatedText = children || obfuscateEmail(email);
  return React__default.createElement("a", Object.assign({
    className: className,
    href: hovered ? emailUrl.href : '#',
    onFocus: handleHover,
    onMouseOver: handleHover
  }, rest), hovered ? displayText : obfuscatedText);
}

exports.Email = Email;
//# sourceMappingURL=react-obfuscate-email.cjs.development.js.map
